summaryrefslogtreecommitdiff
path: root/scripts/imageplugin.sh
diff options
context:
space:
mode:
Diffstat (limited to 'scripts/imageplugin.sh')
-rwxr-xr-xscripts/imageplugin.sh5
1 files changed, 3 insertions, 2 deletions
diff --git a/scripts/imageplugin.sh b/scripts/imageplugin.sh
index 2afd734..73635c1 100755
--- a/scripts/imageplugin.sh
+++ b/scripts/imageplugin.sh
@@ -1,8 +1,9 @@
#!/bin/bash
# script for vdr-imageplugin to convert the selected image to pnm-image
# needs : netpbm-progs > anytopnm pnmscale pnmfile pnmcut pnmflip
#
# History:
+# 2005-06-17 wrong lookup for pnmscale and really are pnmscalefixed used
# 2004-08-12 Initalrelease, Andreas Brachold <vdr04-at-deltab.de>
# base on prior work for convert.sh
# by Onno Kreuzinger <o.kreuzinger-at-kreuzinger.biz>
@@ -46,7 +47,7 @@ fi
ASPECT_RATIO="${ASPECT_RATIO:-"4:3"}"
# check requirement external programs
- REQUIREMENTS="anytopnm pnmscale pnmfile pnmcut pnmflip"
+ REQUIREMENTS="anytopnm pnmscalefixed pnmfile pnmcut pnmflip"
for i in $REQUIREMENTS
do
type "$i" > /dev/null 2>&1
@@ -1,8 +1,9 @@
#!/bin/bash
# script for vdr-imageplugin to convert the selected image to pnm-image
-# needs : netpbm-progs > anytopnm pnmscale pnmfile pnmcut pnmflip
+# needs : netpbm-progs > anytopnm pnmscalefixed pnmfile pnmcut pnmflip
#
# History: